@@ -22,4 +22,7 @@ def statusIsError(status):
         return True
     if status & STATUS_OK == 0:
         return True
-    return False
\ No newline at end of file
+    return False
+
+def statusHasBit(status, bit):
+    return status & bit != 0
\ No newline at end of file
